==> v_chat_sdk-0.6.0.tar.gz: lib/src/dto/create_group_room_dto.dart <==
import 'dart:io';

class CreateGroupRoomDto {
  final List<String> usersEmails;
  final String groupTitle;
  final File groupImage;

//<editor-fold desc="Data Methods">

  const CreateGroupRoomDto({
    required this.usersEmails,
    required this.groupTitle,
    required this.groupImage,
  });

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      (other is CreateGroupRoomDto &&
          runtimeType == other.runtimeType &&
          usersEmails == other.usersEmails &&
          groupTitle == other.groupTitle &&
          groupImage == other.groupImage);

  @override
  int get hashCode =>
      usersEmails.hashCode ^ groupTitle.hashCode ^ groupImage.hashCode;

  @override
  String toString() {
    return 'CreateGroupRoomDto{'
        ' usersEmails: $usersEmails,'
        ' groupTitle: $groupTitle,'
        ' groupImage: $groupImage,'
        '}';
  }

  CreateGroupRoomDto copyWith({
    List<String>? usersEmails,
    String? groupTitle,
    File? groupImage,
  }) {
    return CreateGroupRoomDto(
      usersEmails: usersEmails ?? this.usersEmails,
      groupTitle: groupTitle ?? this.groupTitle,
      groupImage: groupImage ?? this.groupImage,
    );
  }

  Map<String, dynamic> toMap() {
    return {
      'usersEmails': usersEmails,
      'groupTitle': groupTitle,
      'groupImage': groupImage,
    };
  }

  factory CreateGroupRoomDto.fromMap(Map<String, dynamic> map) {
    return CreateGroupRoomDto(
      usersEmails: map['usersEmails'] as List<String>,
      groupTitle: map['groupTitle'] as String,
      groupImage: map['groupImage'] as File,
    );
  }

//</editor-fold>
}

==> v_chat_sdk-1.0.1.tar.gz: lib/src/dto/create_group_room_dto.dart <==
import 'dart:io';

class CreateGroupRoomDto {
  final List<String> usersEmails;
  final String groupTitle;
  final File groupImage;

//<editor-fold desc="Data Methods">

  const CreateGroupRoomDto({
    required this.usersEmails,
    required this.groupTitle,
    required this.groupImage,
  });

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      (other is CreateGroupRoomDto &&
          runtimeType == other.runtimeType &&
          usersEmails == other.usersEmails &&
          groupTitle == other.groupTitle &&
          groupImage == other.groupImage);

  @override
  int get hashCode =>
      usersEmails.hashCode ^ groupTitle.hashCode ^ groupImage.hashCode;

  @override
  String toString() {
    return 'CreateGroupRoomDto{usersEmails: $usersEmails, groupTitle: $groupTitle, groupImage: $groupImage}';
  }

  CreateGroupRoomDto copyWith({
    List<String>? usersEmails,
    String? groupTitle,
    File? groupImage,
  }) {
    return CreateGroupRoomDto(
      usersEmails: usersEmails ?? this.usersEmails,
      groupTitle: groupTitle ?? this.groupTitle,
      groupImage: groupImage ?? this.groupImage,
    );
  }

  Map<String, dynamic> toMap() {
    return {
      'usersEmails': usersEmails,
      'groupTitle': groupTitle,
      'groupImage': groupImage,
    };
  }

  factory CreateGroupRoomDto.fromMap(Map<String, dynamic> map) {
    return CreateGroupRoomDto(
      usersEmails: map['usersEmails'] as List<String>,
      groupTitle: map['groupTitle'] as String,
      groupImage: map['groupImage'] as File,
    );
  }

//</editor-fold>
}
